@@ -1,4 +1,4 @@
-pscore.dist <- function(glmobject, structure.fmla=NULL)
+pscore.dist <- function(glmobject, structure.fmla=NULL,standardization.scale=sd)
   {
 stopifnot(all(c('y', 'linear.predictors','data')%in%names(glmobject)))
 
@@ -11,10 +11,14 @@ structure.fmla <- update.formula(structure.fmla, ZzZz~.)
 if (!all(all.vars(structure.fmla)%in%c('ZzZz',names(model.frame(glmobject)))))
   warning('stratifying variables (in structure.fmla) not in propensity specification')
 }
+szn.scale <- function(x,Tx,standardizer) {
+sqrt( ((sum(!Tx)-1)*standardizer(x[!Tx])^2 + 
+       (sum(!!Tx)-1)*standardizer(x[!!Tx])^2)/
+     (length(x)-2)
+     )
+}
 ZzZz <- glmobject$y>0
-pooled.sd <- sqrt((var(glmobject$linear.predictors[ZzZz])*(sum(ZzZz)-1) +
-                   var(glmobject$linear.predictors[!ZzZz])*(sum(!ZzZz)-1))/
-                  (length(ZzZz)-2))
+pooled.sd <- szn.scale(glmobject$linear.predictors,ZzZz,standardization.scale)
 PpTy <- glmobject$linear.predictors/pooled.sd
 
 attr(structure.fmla, 'generation.increment') <- 1
